package com.mcwl.web.controller.communityCenter;


import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.communityCenter.domain.dto.QuestionDetailRes;
import com.mcwl.communityCenter.domain.dto.QuestionPageRes;
import com.mcwl.communityCenter.domain.dto.QuestionReplyRes;
import com.mcwl.communityCenter.domain.dto.QuestionRes;
import com.mcwl.communityCenter.domain.vo.QuestionVo;
import com.mcwl.communityCenter.service.QuestionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.Objects;

/**
 * 提问
 */
@Api(tags = "提问")
@RestController
@RequestMapping("question")
@RequiredArgsConstructor
public class QuestionController {


    private final QuestionService questionService;

    /**
     * 提问
     */
    @PostMapping("addQuestion")
    @ApiOperation(value = "提问")
    public AjaxResult addQuestion(@RequestBody @Valid QuestionRes questionRes) {


        return questionService.addQuestion(questionRes);

    }


    /**
     * 获取提问列表
     */
    @PostMapping("list")
    @ApiOperation(value = "获取提问列表")
    public TableDataInfo list(@RequestBody @Valid QuestionPageRes questionPageRes) {

        return questionService.list(questionPageRes);
    }

    /**
     * 获取提问图片列表
     */
    @PostMapping("listImage")
    @ApiOperation(value = "获取提问图片列表")
    public TableDataInfo listImage(@RequestBody @Valid QuestionPageRes questionPageRes) {

        return questionService.listImage(questionPageRes);
    }

    /**
     * 获取问题详情
     */
    @PostMapping("detail")
    @ApiOperation(value = "获取问题详情")
    public AjaxResult getQuestionDetail(@RequestBody @Valid QuestionDetailRes questionDetailRes) {
        QuestionVo questionVo = questionService.getDetail(questionDetailRes);
        if (Objects.isNull(questionVo)) {
            return AjaxResult.error("获取详情失败");
        }
        return AjaxResult.success(questionVo);
    }

    /**
     * 回复
     */
    @PostMapping("reply")
    @ApiOperation(value = "回复")
    public AjaxResult reply(@RequestBody @Valid QuestionReplyRes questionReplyRes) {

        return questionService.reply(questionReplyRes);

    }


}
