package com.mcwl.web.controller.resource;

import com.mcwl.common.annotation.RepeatSubmit;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.resource.domain.dto.ModelImageCommentRes;
import com.mcwl.resource.domain.vo.ModelImageCommentVo;
import com.mcwl.resource.service.ModelImageCommentLikeService;
import com.mcwl.resource.service.ModelImageCommentService;
import com.mcwl.resource.service.ModelImageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 图片评论
 */
@Api(tags = "图片评论")
@RestController
@RequestMapping("/imageComment")
@RequiredArgsConstructor
public class ModelImageCommentController {

    private final ModelImageService modelImageService;

    private final ModelImageCommentLikeService modelImageCommentLikeService;

    private final ModelImageCommentService modelImageCommentService;


    /**
     * 图片评论发布
     */
    @ApiOperation(value = "图片评论发布")
    @PostMapping("/comment")
    public AjaxResult comment(@RequestBody ModelImageCommentRes modelImageCommentRes) {
        modelImageCommentService.comment(modelImageCommentRes);
        return AjaxResult.success();
    }

    /**
     * 图片评论点赞/取消
     */
    @ApiOperation(value = "图片评论点赞/取消")
    @RepeatSubmit
    @GetMapping("/commentLike/{commentId}")
    public AjaxResult commentLike(@PathVariable @NotNull(message = "评论id不能为空") Long commentId) {
        modelImageCommentLikeService.like(commentId);
        return AjaxResult.success();
    }

    /**
     * 删除图片评论
     */
    @ApiOperation(value = "删除图片评论")
    @GetMapping("/commentDelete/{commentId}")
    public AjaxResult commentDelete(@PathVariable @NotNull(message = "评论id不能为空") Long commentId) {
        modelImageCommentService.removeById(commentId);
        return AjaxResult.success();
    }

    /**
     * 获取图片评论
     */
    @ApiOperation(value = "获取图片评论")
    @GetMapping("/comment/{imageId}")
    public AjaxResult getComment(@PathVariable @NotNull(message = "图片id不能为空") Long imageId) {
        List<ModelImageCommentVo> modelImageCommentVoList = modelImageCommentService.getComment(imageId);
        return AjaxResult.success(modelImageCommentVoList);
    }


}
