package com.mcwl.web.controller.resource;

import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.resource.domain.ModelProduct;
import com.mcwl.resource.domain.WorkFlow;
import com.mcwl.resource.domain.request.RequestWorkFlow;
import com.mcwl.resource.domain.vo.PageVo;
import com.mcwl.resource.service.impl.WorkFlowServiceImpl;
import com.mcwl.web.controller.common.OssUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


/**
 * 工作流
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.resource
 * @Filename：MallProductController
 * @Description 商品
 * @Date：2024/12/31 10:48
 */
@Api(tags = "工作流")
@RestController
@RequestMapping("/WorkFlow")
public class WorkFlowController extends BaseController {


    @Autowired
    private WorkFlowServiceImpl workFlowService;


    /**
     * 设置工作流的置顶状态
     * @param id
     * @param isTop
     * @return
     */
    @PutMapping("/{id}/top")
    public ResponseEntity<WorkFlow> setworkFlowTop(@PathVariable Long id, @RequestParam boolean isTop) {
        try {
            workFlowService.setworkFlowTop(id, isTop);
            return ResponseEntity.ok().build();
        } catch (Exception e) {
            return ResponseEntity.badRequest().build();
        }
    }


/**
     * 获取所有工作流，按照置顶状态排序
     * @return
     */
    @GetMapping
    public ResponseEntity<List<WorkFlow>> fetchWorkFlowSortedByTopStatus() {
        List<WorkFlow> models = workFlowService.fetchWorkFlowSortedByTopStatus();
        return ResponseEntity.ok(models);
    }



    /***
     * 图片
     * @param file
     * @return
     */
    @ApiOperation(value = "图片")
    @PostMapping("/file")
    public AjaxResult Malifile(@RequestParam MultipartFile file){

        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }

    /***
     *
     * zip
     * @param file
     * @return
     */
    @ApiOperation(value = "zip")
    @PostMapping("/zipUrlFile")
    public AjaxResult zipUrlFile(@RequestParam MultipartFile file){
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /***
     *
     * 下载zip
     * @param file
     * @return
     */
    @ApiOperation(value = "下载zip")
    @PostMapping("/zipUrl")
    public AjaxResult zipUrl(@RequestParam MultipartFile file){
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /**
     * 添加工作流
     * @param requestWorkFlow
     * @return
     */
    @ApiOperation(value = "添加工作流")
    @PostMapping("/addWorkFlow")
    public AjaxResult addWorkFlow(@RequestBody RequestWorkFlow requestWorkFlow){

        return workFlowService.addWorkFlow(requestWorkFlow);
    }

    /**
     * 修改工作流
     * @param requestWorkFlow
     * @return
     */
    @ApiOperation(value = "修改工作流")
    @PostMapping("/updateWorkFlow")
    public AjaxResult updateWorkFlow(@RequestBody RequestWorkFlow requestWorkFlow){

        workFlowService.updateWorkFlow(requestWorkFlow);

        return AjaxResult.success("修改成功");
    }

    /**
     * 删除工作流
     * @param id
     * @return
     */
    @ApiOperation(value = "删除工作流")
    @GetMapping("/deleteWorkFlow")
    public AjaxResult deleteWorkFlow(@RequestParam Long id){

        workFlowService.deleteWorkFlow(id);
        return AjaxResult.success("删除成功");
    }

    /**
     * 查询工作流列表
     * @param pageVo
     * @return
     */
    @ApiOperation(value = "查询工作流列表")
    @PostMapping("/selectWorkFlow")
    public AjaxResult selectWorkFlow(@RequestBody PageVo pageVo){

        return workFlowService.selectWorkFlow(pageVo);
    }


    /**
     * 查询工作流详情
     * @param id
     * @return
     */
    @ApiOperation(value = "查询工作流详情")
    @GetMapping("/selectWorkFlowById")
    public AjaxResult selectWorkFlowById(@RequestParam Long id){

        return workFlowService.selectWorkFlowById(id);
    }

}
