package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.exception.ServiceException;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.ModelImage;
import com.mcwl.resource.domain.ModelImageLike;
import com.mcwl.resource.mapper.ModelImageLikeMapper;
import com.mcwl.resource.mapper.ModelImageMapper;
import com.mcwl.resource.service.ModelImageLikeService;
import com.mcwl.resource.service.ModelImageService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;
import java.util.Objects;

@Service
@RequiredArgsConstructor
public class ModelImageLikeServiceImpl extends ServiceImpl<ModelImageLikeMapper, ModelImageLike> implements ModelImageLikeService {

    private final ModelImageMapper modelImageMapper;

    @Override
    @Transactional
    public void like(Long imageId) {
        ModelImage modelImage = modelImageMapper.selectById(imageId);
        if (Objects.isNull(modelImage)) {
            throw new ServiceException("该图片不存在或已下架");
        }
        Long userId = SecurityUtils.getUserId();
        ModelImageLike modelImageLike = baseMapper.getLikeImage(userId, imageId);
        if (Objects.nonNull(modelImageLike)) {
            if (Objects.equals(modelImageLike.getDelFlag(), "0")) {
                modelImage.setLikeNum(modelImage.getLikeNum() - 1);
            } else {
                modelImage.setLikeNum(modelImage.getLikeNum() + 1);
            }
            // 更新点赞记录
            baseMapper.updateDelFlagById(userId, imageId);
            // 更新图片点赞数
            modelImageMapper.updateById(modelImage);
            return;
        }

        // 添加点赞记录
        modelImageLike = new ModelImageLike();
        modelImageLike.setUserId(userId);
        modelImageLike.setModelImageId(imageId);
        modelImageLike.setCreateBy(SecurityUtils.getUsername());
        modelImageLike.setUpdateBy(SecurityUtils.getUsername());
        modelImageLike.setUpdateTime(new Date());
        baseMapper.insert(modelImageLike);

        // 更新图片点赞数
        modelImage.setLikeNum(modelImage.getLikeNum() + 1);
        modelImageMapper.updateById(modelImage);
    }

    @Override
    public void setModelImageTop(Long id, boolean isTop) {
        modelImageMapper.setModelImageTop(id,isTop?0:1);
    }

    @Override
    public List<ModelImage> fetchModelImageSortedByTopStatus() {
        return modelImageMapper.fetchModelImageSortedByTopStatus();
    }
}
