package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.exception.ServiceException;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.*;
import com.mcwl.resource.mapper.ModelMapper;
import com.mcwl.resource.mapper.ModelLikeMapper;
import com.mcwl.resource.service.ModelLikeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.Objects;

/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.resource.service.impl
 * @Filename：ModelLikeServiceImpl
 * @Description TODO
 * @Date：2025/1/12 12:05
 */
@Service
public class ModelLikeServiceImpl extends ServiceImpl<ModelLikeMapper, ModelLike> implements ModelLikeService {


    @Autowired
    private ModelMapper modelMapper;

    @Override
    @Transactional
    public void like(Long modelId) {
        ModelProduct model = modelMapper.selectById(modelId);
        if (Objects.isNull(model)) {
            throw new ServiceException("该模型不存在或已下架");
        }
        Long userId = SecurityUtils.getUserId();
        ModelLike modelLike = baseMapper.getLike(userId, modelId);
        if (Objects.nonNull(modelLike)) {
            if (Objects.equals(modelLike.getDelFlag(), "0")) {
                modelLike.setDelFlag("1");
                model.setNumbers(model.getNumbers() - 1);
            } else {
                modelLike.setDelFlag("0");
                model.setNumbers(model.getNumbers() + 1);
            }
            // 更新点赞记录
            baseMapper.updateById(modelLike);
            // 更新图片点赞数
            modelMapper.updateById(model);
            return;
        }

        // 添加点赞记录
        modelLike = new ModelLike();
        modelLike.setUserId(userId);
        modelLike.setModelId(modelId);
        modelLike.setCreateBy(SecurityUtils.getUsername());
        modelLike.setUpdateBy(SecurityUtils.getUsername());
        modelLike.setUpdateTime(new Date());
        baseMapper.insert(modelLike);

        // 更新图片点赞数
        model.setNumbers(model.getNumbers() + 1);
        modelMapper.updateById(model);
    }
}
