package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.exception.ServiceException;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.WorkFlow;
import com.mcwl.resource.domain.WorkFlowLike;
import com.mcwl.resource.mapper.WorkFlowLikeMapper;
import com.mcwl.resource.mapper.WorkFlowMapper;
import com.mcwl.resource.service.WorkFlowLikeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.Objects;

/**
 * 工作流点赞
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.resource.service.impl
 * @Filename：ModelLikeServiceImpl
 * @Description TODO
 * @Date：2025/1/12 12:05
 */
@Service
public class WorkFlowLikeServiceImpl extends ServiceImpl<WorkFlowLikeMapper, WorkFlowLike> implements WorkFlowLikeService {


    @Autowired
    private WorkFlowMapper workFlowMapper;

    @Override
    @Transactional
    public void like(Long modelId) {
        WorkFlow workFlow = workFlowMapper.selectById(modelId);
        if (Objects.isNull(workFlow)) {
            throw new ServiceException("该工作流不存在或已下架");
        }
        Long userId = SecurityUtils.getUserId();
        WorkFlowLike workFlowLike = baseMapper.getLike(userId, modelId);
        if (Objects.nonNull(workFlowLike)) {
            if (Objects.equals(workFlowLike.getDelFlag(), "0")) {
                workFlowLike.setDelFlag("1");
                workFlow.setLikeCount(workFlow.getLikeCount() - 1);
            } else {
                workFlowLike.setDelFlag("0");
                workFlow.setLikeCount(workFlow.getLikeCount() + 1);
            }
            // 更新点赞记录
            baseMapper.updateStatus(workFlowLike);
            // 更新图片点赞数
            workFlowMapper.updateById(workFlow);
            return;
        }

        // 添加点赞记录
        workFlowLike = new WorkFlowLike();
        workFlowLike.setUserId(userId);
        workFlowLike.setWorkFlowId(modelId);
        workFlowLike.setCreateBy(SecurityUtils.getUsername());
        workFlowLike.setUpdateBy(SecurityUtils.getUsername());
        workFlowLike.setUpdateTime(new Date());
        baseMapper.insert(workFlowLike);

        // 更新图片点赞数
        workFlow.setLikeCount(workFlow.getLikeCount() + 1);
        workFlowMapper.updateById(workFlow);
    }

}
